# Snapshot report for `test/js/successTest.js`

The actual snapshot is saved in `successTest.js.snap`.

Generated by [AVA](https://ava.li).

## structure

> Snapshot 1

    ServiceReply {
      success: Success {
        message: 'success message',
        title: 'success title',
      },
    }
